@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (C) 2015 OpenCraft
 # License: AGPLv3
@@ -10,13 +9,10 @@ StudioEditableXBlockMixin to your XBlock.
 
 # Imports ###########################################################
 
-from __future__ import absolute_import
+
 import logging
 import simplejson as json
 
-import six
-from six import text_type
-
 from xblock.core import XBlock
 from xblock.fields import Scope, JSONField, List, Integer, Float, Boolean, String, DateTime
 from xblock.exceptions import JsonHandlerError, NoSuchViewError
@@ -33,7 +29,7 @@ loader = ResourceLoader(__name__)
 # Classes ###########################################################
 
 
-class FutureFields(object):
+class FutureFields:
     """
     A helper class whose attribute values come from the specified dictionary or fallback object.
 
@@ -69,7 +65,7 @@ class FutureFields(object):
             return getattr(self._fallback_obj, name)
 
 
-class StudioEditableXBlockMixin(object):
+class StudioEditableXBlockMixin:
     """
     An XBlock mixin to provide a configuration UI for an XBlock in Studio.
     """
@@ -184,7 +180,7 @@ class StudioEditableXBlockMixin(object):
                 info['values'] = values
             else:
                 # e.g. [1, 2, 3] - we need to convert it to the [{"display_name": x, "value": x}] format
-                info['values'] = [{"display_name": text_type(val), "value": val} for val in values]
+                info['values'] = [{"display_name": str(val), "value": val} for val in values]
             info['has_values'] = 'values' in info
         if info["type"] in ("list", "set") and field.runtime_options.get('list_values_provider'):
             list_values = field.runtime_options['list_values_provider'](self)
@@ -198,7 +194,7 @@ class StudioEditableXBlockMixin(object):
             else:
                 # e.g. [1, 2, 3] - we need to convert it to the [{"display_name": x, "value": x}] format
                 list_values = [json.dumps(val) for val in list_values]
-                list_values = [{"display_name": text_type(val), "value": val} for val in list_values]
+                list_values = [{"display_name": str(val), "value": val} for val in list_values]
             info['list_values'] = list_values
             info['has_list_values'] = True
         return info
@@ -216,7 +212,7 @@ class StudioEditableXBlockMixin(object):
                 if isinstance(field, JSONField):
                     values[field_name] = field.from_json(data['values'][field_name])
                 else:
-                    raise JsonHandlerError(400, "Unsupported field type: {}".format(field_name))
+                    raise JsonHandlerError(400, f"Unsupported field type: {field_name}")
             elif field_name in data['defaults'] and field.is_set_on(self):
                 to_reset.append(field_name)
         self.clean_studio_edits(values)
@@ -230,7 +226,7 @@ class StudioEditableXBlockMixin(object):
         )
         self.validate_field_data(validation, preview_data)
         if validation:
-            for field_name, value in six.iteritems(values):
+            for field_name, value in values.items():
                 setattr(self, field_name, value)
             for field_name in to_reset:
                 self.fields[field_name].delete_from(self)
@@ -268,12 +264,12 @@ class StudioEditableXBlockMixin(object):
         Subclasses should override validate_field_data() to validate fields and override this
         only for validation not related to this block's field values.
         """
-        validation = super(StudioEditableXBlockMixin, self).validate()
+        validation = super().validate()
         self.validate_field_data(validation, self)
         return validation
 
 
-class StudioContainerXBlockMixin(object):
+class StudioContainerXBlockMixin:
     """
     An XBlock mixin to provide convenient use of an XBlock in Studio
     that wants to allow the user to assign children to it.
@@ -300,7 +296,7 @@ class StudioContainerXBlockMixin(object):
             fragment.add_fragment_resources(rendered_child)
 
             contents.append({
-                'id': text_type(child.scope_ids.usage_id),
+                'id': str(child.scope_ids.usage_id),
                 'content': rendered_child.content
             })
 
@@ -340,7 +336,7 @@ class StudioContainerXBlockMixin(object):
         return self.student_view(context)
 
 
-class NestedXBlockSpec(object):
+class NestedXBlockSpec:
     """
     Class that allows detailed specification of allowed nested XBlocks. For use with
     StudioContainerWithNestedXBlocksMixin.allowed_nested_blocks
@@ -396,7 +392,7 @@ class NestedXBlockSpec(object):
         return self._boilerplate
 
 
-class XBlockWithPreviewMixin(object):
+class XBlockWithPreviewMixin:
     """
     An XBlock mixin providing simple preview view. It is to be used with StudioContainerWithNestedXBlocksMixin to
     avoid adding studio wrappers (title, edit button, etc.) to a block when it is rendered as child in parent's
